@@ -20,8 +20,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -45,12 +45,12 @@ class CfnPipeline(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
+        name: builtins.str,
         parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
-        activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        description: typing.Optional[str] = None,
+        activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        description: typing.Optional[builtins.str] = None,
         parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]] = None,
         pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]] = None,
@@ -92,27 +92,28 @@ class CfnPipeline(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
         see
@@ -120,11 +121,11 @@ class CfnPipeline(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
@@ -136,16 +137,18 @@ class CfnPipeline(
         """
         return jsii.get(self, "parameterObjects")
 
-    @parameter_objects.setter
+    @parameter_objects.setter # type: ignore
     def parameter_objects(
         self,
         value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="activate")
-    def activate(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def activate(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
@@ -153,15 +156,16 @@ class CfnPipeline(
         """
         return jsii.get(self, "activate")
 
-    @activate.setter
+    @activate.setter # type: ignore
     def activate(
-        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "activate", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
         see
@@ -169,11 +173,11 @@ class CfnPipeline(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
@@ -185,14 +189,14 @@ class CfnPipeline(
         """
         return jsii.get(self, "parameterValues")
 
-    @parameter_values.setter
+    @parameter_values.setter # type: ignore
     def parameter_values(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
@@ -204,14 +208,14 @@ class CfnPipeline(
         """
         return jsii.get(self, "pipelineObjects")
 
-    @pipeline_objects.setter
+    @pipeline_objects.setter # type: ignore
     def pipeline_objects(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
@@ -223,7 +227,7 @@ class CfnPipeline(
         """
         return jsii.get(self, "pipelineTags")
 
-    @pipeline_tags.setter
+    @pipeline_tags.setter # type: ignore
     def pipeline_tags(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]],
@@ -243,9 +247,9 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            key: str,
-            ref_value: typing.Optional[str] = None,
-            string_value: typing.Optional[str] = None,
+            key: builtins.str,
+            ref_value: typing.Optional[builtins.str] = None,
+            string_value: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param key: ``CfnPipeline.FieldProperty.Key``.
@@ -255,7 +259,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
             }
             if ref_value is not None:
@@ -264,36 +268,40 @@ class CfnPipeline(
                 self._values["string_value"] = string_value
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.FieldProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def ref_value(self) -> typing.Optional[str]:
+        def ref_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.RefValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
             """
-            return self._values.get("ref_value")
+            result = self._values.get("ref_value")
+            return result
 
         @builtins.property
-        def string_value(self) -> typing.Optional[str]:
+        def string_value(self) -> typing.Optional[builtins.str]:
             """``CfnPipeline.FieldProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -307,7 +315,7 @@ class CfnPipeline(
         name_mapping={"key": "key", "string_value": "stringValue"},
     )
     class ParameterAttributeProperty:
-        def __init__(self, *, key: str, string_value: str) -> None:
+        def __init__(self, *, key: builtins.str, string_value: builtins.str) -> None:
             """
             :param key: ``CfnPipeline.ParameterAttributeProperty.Key``.
             :param string_value: ``CfnPipeline.ParameterAttributeProperty.StringValue``.
@@ -315,33 +323,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "string_value": string_value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def string_value(self) -> str:
+        def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            assert result is not None, "Required property 'string_value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -359,7 +371,7 @@ class CfnPipeline(
             self,
             *,
             attributes: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]],
-            id: str,
+            id: builtins.str,
         ) -> None:
             """
             :param attributes: ``CfnPipeline.ParameterObjectProperty.Attributes``.
@@ -368,7 +380,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "attributes": attributes,
                 "id": id,
             }
@@ -382,21 +394,25 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
             """
-            return self._values.get("attributes")
+            result = self._values.get("attributes")
+            assert result is not None, "Required property 'attributes' is missing"
+            return result
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.ParameterObjectProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -410,7 +426,7 @@ class CfnPipeline(
         name_mapping={"id": "id", "string_value": "stringValue"},
     )
     class ParameterValueProperty:
-        def __init__(self, *, id: str, string_value: str) -> None:
+        def __init__(self, *, id: builtins.str, string_value: builtins.str) -> None:
             """
             :param id: ``CfnPipeline.ParameterValueProperty.Id``.
             :param string_value: ``CfnPipeline.ParameterValueProperty.StringValue``.
@@ -418,33 +434,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "id": id,
                 "string_value": string_value,
             }
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
         @builtins.property
-        def string_value(self) -> str:
+        def string_value(self) -> builtins.str:
             """``CfnPipeline.ParameterValueProperty.StringValue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
             """
-            return self._values.get("string_value")
+            result = self._values.get("string_value")
+            assert result is not None, "Required property 'string_value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -462,8 +482,8 @@ class CfnPipeline(
             self,
             *,
             fields: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]],
-            id: str,
-            name: str,
+            id: builtins.str,
+            name: builtins.str,
         ) -> None:
             """
             :param fields: ``CfnPipeline.PipelineObjectProperty.Fields``.
@@ -473,7 +493,7 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "fields": fields,
                 "id": id,
                 "name": name,
@@ -488,30 +508,36 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
             """
-            return self._values.get("fields")
+            result = self._values.get("fields")
+            assert result is not None, "Required property 'fields' is missing"
+            return result
 
         @builtins.property
-        def id(self) -> str:
+        def id(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Id``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
             """
-            return self._values.get("id")
+            result = self._values.get("id")
+            assert result is not None, "Required property 'id' is missing"
+            return result
 
         @builtins.property
-        def name(self) -> str:
+        def name(self) -> builtins.str:
             """``CfnPipeline.PipelineObjectProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            assert result is not None, "Required property 'name' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -525,7 +551,7 @@ class CfnPipeline(
         name_mapping={"key": "key", "value": "value"},
     )
     class PipelineTagProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnPipeline.PipelineTagProperty.Key``.
             :param value: ``CfnPipeline.PipelineTagProperty.Value``.
@@ -533,33 +559,37 @@ class CfnPipeline(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnPipeline.PipelineTagProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -585,10 +615,10 @@ class CfnPipelineProps:
     def __init__(
         self,
         *,
-        name: str,
+        name: builtins.str,
         parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
-        activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        description: typing.Optional[str] = None,
+        activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        description: typing.Optional[builtins.str] = None,
         parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
         pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
@@ -606,7 +636,7 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "parameter_objects": parameter_objects,
         }
@@ -622,13 +652,15 @@ class CfnPipelineProps:
             self._values["pipeline_tags"] = pipeline_tags
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DataPipeline::Pipeline.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
     def parameter_objects(
@@ -639,25 +671,31 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
         """
-        return self._values.get("parameter_objects")
+        result = self._values.get("parameter_objects")
+        assert result is not None, "Required property 'parameter_objects' is missing"
+        return result
 
     @builtins.property
-    def activate(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def activate(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
         """
-        return self._values.get("activate")
+        result = self._values.get("activate")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DataPipeline::Pipeline.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def parameter_values(
@@ -668,7 +706,8 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
         """
-        return self._values.get("parameter_values")
+        result = self._values.get("parameter_values")
+        return result
 
     @builtins.property
     def pipeline_objects(
@@ -679,7 +718,8 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
         """
-        return self._values.get("pipeline_objects")
+        result = self._values.get("pipeline_objects")
+        return result
 
     @builtins.property
     def pipeline_tags(
@@ -690,12 +730,13 @@ class CfnPipelineProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
         """
-        return self._values.get("pipeline_tags")
+        result = self._values.get("pipeline_tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
